@@ -68,6 +68,21 @@ def all_required_inputs(component):
     return not is_input_missing
 
 
+def component_guid(component):
+    """Get the unique ID associated with a specific component.
+
+    This ID remains the same every time that the component is run.
+
+    Args:
+        component: The grasshopper component object, which can be accessed through
+            the ghenv.Component call within Grasshopper API.
+
+    Returns:
+        Text string for the component's unique ID.
+    """
+    return component.GetHashCode().ToString()
+
+
 def wrap_output(output):
     """Wrap Python objects as Grasshopper generic objects.
 
@@ -88,6 +103,22 @@ def wrap_output(output):
         raise ValueError('Failed to wrap {}:\n{}.'.format(output, e))
 
 
+def longest_list(values, index):
+    """Get a value from a list while applying Grasshopper's longest-list logic.
+
+    Args:
+        values: An array of values from which a value will be pulled following
+            longest list logic.
+        index: Integer for the index of the item in the list to return. If this
+            index is greater than the length of the values, the last item of the
+            list will be returned.
+    """
+    try:
+        return values[index]
+    except IndexError:
+        return values[-1]
+
+
 def data_tree_to_list(input):
     """Convert a grasshopper DataTree to nested lists of lists.
 
@@ -182,3 +213,38 @@ def unflatten_to_data_tree(all_data, pattern):
         data_tree.AddRange(all_data[index - count:index], path)
 
     return data_tree
+
+
+def hide_output(component, output_index):
+    """Hide one of the outputs of a component.
+
+    Args:
+        component: The grasshopper component object, which can be accessed through
+            the ghenv.Component call within Grasshopper API.
+        output_index: Integer for the index of the output to hide.
+    """
+    component.Params.Output[output_index].Hidden = True
+
+
+def show_output(component, output_index):
+    """Show one of the outputs of a component.
+
+    Args:
+        component: The grasshopper component object, which can be accessed through
+            the ghenv.Component call within Grasshopper API.
+        output_index: Integer for the index of the output to hide.
+    """
+    component.Params.Output[output_index].Hidden = False
+
+
+def schedule_solution(component, milliseconds):
+    """Schedule a new Grasshopper solution after a specified time interval.
+
+    Args:
+        component: The grasshopper component object, which can be accessed through
+            the ghenv.Component call within Grasshopper API.
+        milliseconds: Integer for the number of milliseconds after which the
+            solution should happen.
+    """
+    doc = component.OnPingDocument()
+    doc.ScheduleSolution(milliseconds)
